diff --git a/build.properties b/build.properties
index 7a5a597..daa4b7e 100644
--- a/build.properties
+++ b/build.properties
@@ -1,6 +1,6 @@
# Project
proj.name=mobibot
-proj.version=0.3
+proj.version=0.4
proj.package=net.thauvin.erik.mobibot
proj.run=${proj.package}.Mobibot
diff --git a/buildnum.properties b/buildnum.properties
index 1ad1f24..2605a1b 100644
--- a/buildnum.properties
+++ b/buildnum.properties
@@ -1,3 +1,3 @@
#ANT Task: ch.oscg.jreleaseinfo.BuildNumberHandler
-#Thu Oct 11 18:06:05 PDT 2007
-build.num.last=73
+#Thu Oct 11 18:41:48 PDT 2007
+build.num.last=0
diff --git a/mobibot.iws b/mobibot.iws
index ced1546..f1f23c2 100644
--- a/mobibot.iws
+++ b/mobibot.iws
@@ -19,8 +19,9 @@
-
+
+
@@ -159,28 +160,28 @@
-
-
-
-
-
-
-
-
-
-
+
-
+
-
-
+
+
-
+
+
+
+
+
+
+
+
+
+
@@ -372,20 +373,34 @@
+
+
+
+
+
+
+
+
+
+
+
+
+
+
-
+
-
+
@@ -476,6 +491,18 @@
+
+
+
+
+
+
+
+
+
+
+
+
@@ -524,18 +551,6 @@
-
-
-
-
-
-
-
-
-
-
-
-
@@ -789,16 +804,30 @@
-
+
-
+
-
+
-
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
@@ -852,9 +881,9 @@
-
+
-
+
diff --git a/src/net/thauvin/erik/mobibot/ReleaseInfo.java b/src/net/thauvin/erik/mobibot/ReleaseInfo.java
index b60bc18..bb75834 100644
--- a/src/net/thauvin/erik/mobibot/ReleaseInfo.java
+++ b/src/net/thauvin/erik/mobibot/ReleaseInfo.java
@@ -1,5 +1,5 @@
/* Created by JReleaseInfo AntTask from Open Source Competence Group */
-/* Creation date Thu Oct 11 18:06:05 PDT 2007 */
+/* Creation date Thu Oct 11 18:41:48 PDT 2007 */
package net.thauvin.erik.mobibot;
import java.util.Date;
@@ -20,21 +20,21 @@ public class ReleaseInfo {
}
- /** buildDate (set during build process to 1192151165055L). */
- private static final Date buildDate = new Date(1192151165055L);
+ /** buildDate (set during build process to 1192153308645L). */
+ private static final Date buildDate = new Date(1192153308645L);
/**
- * Get buildDate (set during build process to Thu Oct 11 18:06:05 PDT 2007).
+ * Get buildDate (set during build process to Thu Oct 11 18:41:48 PDT 2007).
* @return Date buildDate
*/
public static Date getBuildDate() { return buildDate; }
/**
- * Get buildNumber (set during build process to 73).
+ * Get buildNumber (set during build process to 0).
* @return int buildNumber
*/
- public static int getBuildNumber() { return 73; }
+ public static int getBuildNumber() { return 0; }
/** project (set during build process to "mobibot"). */
@@ -47,11 +47,11 @@ public class ReleaseInfo {
public static String getProject() { return project; }
- /** version (set during build process to "0.3"). */
- private static final String version = "0.3";
+ /** version (set during build process to "0.4"). */
+ private static final String version = "0.4";
/**
- * Get version (set during build process to "0.3").
+ * Get version (set during build process to "0.4").
* @return String version
*/
public static String getVersion() { return version; }